@@ -1,7 +1,7 @@
 package App::lcpan;
 
-our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1419,9 +1419,9 @@ sub modules {
         my $sort = $args{sort} // '';
         my $is_desc = $sort =~ s/^-//;
         my $order;
-        if ($sort eq 'name') { $order = 'name' }
         if ($sort eq 'author') { $order = 'author' }
         elsif ($sort eq 'rdeps') { $order = 'rdeps' }
+        else { $order = 'name' }
         $order .= " DESC" if $is_desc;
         $order;
     };
@@ -2212,7 +2212,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.40 of App::lcpan (from Perl distribution App-lcpan), released on 2015-06-16.
+This document describes version 0.41 of App::lcpan (from Perl distribution App-lcpan), released on 2015-06-17.
 
 =head1 SYNOPSIS
 
