@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::authorrdeps;
 
-our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010;
 use strict;
@@ -24,11 +24,11 @@ $SPEC{'handle_cmd'} = {
         #},
         user_author => {
             schema => ['array*', of=>'str*'],
-            completion => \&App::lcpan::_complete_cpanid,
+            element_completion => \&App::lcpan::_complete_cpanid,
         },
         user_author_isnt => {
             schema => ['array*', of=>'str*'],
-            completion => \&App::lcpan::_complete_cpanid,
+            element_completion => \&App::lcpan::_complete_cpanid,
         },
     },
 };
@@ -70,7 +70,7 @@ App::lcpan::Cmd::authorrdeps - Find distributions that use one of author's modul
 
 =head1 VERSION
 
-This document describes version 0.40 of App::lcpan::Cmd::authorrdeps (from Perl distribution App-lcpan), released on 2015-06-16.
+This document describes version 0.41 of App::lcpan::Cmd::authorrdeps (from Perl distribution App-lcpan), released on 2015-06-17.
 
 =head1 FUNCTIONS
 
